@@ -11,7 +11,7 @@ use File::Slurp;
 
 with 'Bio::Grid::Run::SGE::Role::Indexable';
 
-our $VERSION = '0.0387_01'; # VERSION
+our $VERSION = 0.01_01;
 
 sub BUILD {
   my ($self) = @_;
@@ -21,61 +21,29 @@ sub BUILD {
   if ( -f $self->idx_file ) {
     $self->_load_index;
   }
-  # always reindex list based indices. Lists can easily change
-  # and it is not straight forward to check changes
-  $self->_reindexing_necessary(1);
 
   return $self;
 }
 
-before 'create' => sub {
-  my $self = shift;
-
-  print STDERR "SKIPPING INDEXING STEP, THE INDEX IS UP TO DATE\n"
-    if ( $self->_is_indexed );
-
-  $self->_check_writable;
-
-  print STDERR "INDEXING ....\n";
-};
-
 sub create {
-  my ( $self, $elements ) = @_;
+  my ( $self, $input_files ) = @_;
 
-  return $self if ( $self->_is_indexed );
+  if ( $self->_is_indexed ) {
+
+    print STDERR "SKIPPING INDEXING STEP, THE INDEX IS UP TO DATE\n";
+    return $self;
+  }
+  confess 'No write permission, set write_flag to write' unless ( $self->writeable );
 
   my $chunk_size = $self->chunk_size;
 
-  my @current_chunk;
-  my $chunk_elem_count = 0;
-  my @idx;
-
-  for my $e (@$elements) {
-    if ( $chunk_elem_count && $chunk_elem_count % $chunk_size == 0 ) {
-      $chunk_elem_count = 0;
-
-      push @idx, [@current_chunk];
-      undef @current_chunk;
-    }
-    push @current_chunk, $e;
-    $chunk_elem_count++;
-
-  }
-
-  push @idx, [@current_chunk] if ( @current_chunk && @current_chunk > 0 );
-
-  $self->idx( \@idx );
+  #FIXME chunks should be possible
+  $self->idx( [@$input_files] );
 
   $self->_store;
   return $self;
 }
 
-sub _check_writable {
-  my $self = shift;
-  confess 'No write permission, set write_flag to write' unless ( $self->writeable );
-
-}
-
 sub _is_indexed {
   my ($self) = @_;
 
