@@ -6,7 +6,7 @@ use warnings;
 use strict;
 use Carp;
 
-our $VERSION = '0.0387_01'; # VERSION
+our $VERSION = 0.01_01;
 use Bio::Gonzales::Util::File qw/slurpc open_on_demand/;
 has log_file => ( is => 'rw', required => 1 );
 has log_data => ( is => 'rw' );
@@ -66,7 +66,7 @@ sub to_script {
 
   print $fh join( ' ', $perl, @job_cmd ), "\n";
 
-  $fh->close unless $was_open;
+  close $fh unless $was_open;
 }
 
 __PACKAGE__->meta->make_immutable();
