@@ -3,7 +3,6 @@ package Bio::Grid::Run::SGE::Worker;
 use warnings;
 use strict;
 use Mouse;
-use 5.010;
 use Storable;
 use Data::Dumper;
 use Carp;
@@ -15,7 +14,7 @@ use IO::Handle;
 
 use Cwd qw/fastcwd/;
 
-our $VERSION = '0.0387_01'; # VERSION
+our $VERSION = 0.01_01;
 
 has [qw/config_file task/] => ( is => 'rw', required => 1 );
 has [qw/range _part_size/] => ( is => 'rw' );
@@ -129,7 +128,6 @@ sub run {
   # adjust config for main task
   $c->{part_size} = $self->_part_size;
   $c->{job_id}    = $self->job_id . "." . $self->id;
-  $c->{nslots}    = $ENV{NSLOTS} // 1;
 
   while ( my $task_params = $next_task->() ) {
     my $infiles       = $task_params->{infiles};
@@ -142,11 +140,8 @@ sub run {
     my $task_time = time;
 
     #RUN TASK
-    my $return_status = $self->task->( $c, $result_prefix, @{$infiles} );
-    unless ($return_status) {
+    unless ( $self->task->( $c, $result_prefix, @{$infiles} ) ) {
       $self->log_status( "comp.task.exit.error:: $task_id " . join( "#\0#", @$infiles, $result_prefix ) );
-    } elsif ( $return_status < 0 ) {
-      $self->log_status("comp.task.exit.skip:: $task_id");
     } else {
       $self->log_status("comp.task.exit.success:: $task_id");
     }
@@ -216,7 +211,7 @@ sub _create_task_iterator {
       } else {
         open my $in_fh, '>', $infile_template or confess "Can't open filehandle: $!";
         print $in_fh $comb->[$i];
-        $in_fh->close;
+        close $in_fh;
         push @infiles,      $infile_template;
         push @is_temp_file, 1;
       }
@@ -237,7 +232,7 @@ sub _create_task_iterator {
 sub _log_current_settings {
   my ($self) = @_;
 
-  $self->log_status( "init: " . localtime(time) );
+  $self->log_status("init");
   $self->log_status( "config: " . $self->config_file );
   $self->log_status( "id: " . $self->id );
   $self->log_status( "job_id: " . $self->job_id );
